==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMReturnSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JVMReturnSpecBuilder extends JVMReturnSpecFluentImpl<JVMReturnSpecBuilder> implements VisitableBuilder<JVMReturnSpec,JVMReturnSpecBuilder>{
  public JVMReturnSpecBuilder() {
    this(false);
  }
  public JVMReturnSpecBuilder(Boolean validationEnabled) {
    this(new JVMReturnSpec(), validationEnabled);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JVMReturnSpec(), validationEnabled);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,JVMReturnSpec instance) {
    this(fluent, instance, false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,JVMReturnSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    if (instance != null) {
      fluent.withClassName(instance.getClassName());
      fluent.withMethod(instance.getMethod());
      fluent.withPid(instance.getPid());
      fluent.withPort(instance.getPort());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JVMReturnSpecBuilder(JVMReturnSpec instance) {
    this(instance,false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    if (instance != null) {
      this.withClassName(instance.getClassName());
      this.withMethod(instance.getMethod());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  JVMReturnSpecFluent<?> fluent;
  Boolean validationEnabled;
  public JVMReturnSpec build() {
    JVMReturnSpec buildable = new JVMReturnSpec(fluent.getClassName(),fluent.getMethod(),fluent.getPid(),fluent.getPort(),fluent.getValue());
    return buildable;
  }
  
}

==> chaosmesh-model-6.8.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/JVMReturnSpecBuilder.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class JVMReturnSpecBuilder extends JVMReturnSpecFluent<JVMReturnSpecBuilder> implements VisitableBuilder<JVMReturnSpec,JVMReturnSpecBuilder>{
  public JVMReturnSpecBuilder() {
    this(false);
  }
  public JVMReturnSpecBuilder(Boolean validationEnabled) {
    this(new JVMReturnSpec(), validationEnabled);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new JVMReturnSpec(), validationEnabled);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,JVMReturnSpec instance) {
    this(fluent, instance, false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpecFluent<?> fluent,JVMReturnSpec instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    instance = (instance != null ? instance : new JVMReturnSpec());

    if (instance != null) {
      fluent.withClassName(instance.getClassName());
      fluent.withMethod(instance.getMethod());
      fluent.withPid(instance.getPid());
      fluent.withPort(instance.getPort());
      fluent.withValue(instance.getValue());
      fluent.withClassName(instance.getClassName());
      fluent.withMethod(instance.getMethod());
      fluent.withPid(instance.getPid());
      fluent.withPort(instance.getPort());
      fluent.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  public JVMReturnSpecBuilder(JVMReturnSpec instance) {
    this(instance,false);
  }
  public JVMReturnSpecBuilder(JVMReturnSpec instance,Boolean validationEnabled) {
    this.fluent = this; 
    instance = (instance != null ? instance : new JVMReturnSpec());

    if (instance != null) {
      this.withClassName(instance.getClassName());
      this.withMethod(instance.getMethod());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withValue(instance.getValue());
      this.withClassName(instance.getClassName());
      this.withMethod(instance.getMethod());
      this.withPid(instance.getPid());
      this.withPort(instance.getPort());
      this.withValue(instance.getValue());
    }
    this.validationEnabled = validationEnabled; 
  }
  JVMReturnSpecFluent<?> fluent;
  Boolean validationEnabled;
  public JVMReturnSpec build() {
    JVMReturnSpec buildable = new JVMReturnSpec(fluent.getClassName(),fluent.getMethod(),fluent.getPid(),fluent.getPort(),fluent.getValue());
    return buildable;
  }
  
}
